# -*- coding: utf-8 -*-
"""
Created on Mon Jan 13 11:38:51 2025

@author: admin
"""

import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from statsmodels.tsa.stattools import ccf
from pptx import Presentation
from pptx.util import Inches

# Define paths
data_path = r"D:\Febin\MMM Workshop\MMM Workshop Python Scripts\CCF Plot\MMM_Workshop_Data.xlsx"  # Path to your data file
output_folder = "D:/Febin/MMM Workshop/CCF Plots_py2"  # Folder to save the PNG images
save_path = r"D:\Febin\MMM Workshop\CCF Plots_py\CCF_Plot.pptx"  # Path to save the PowerPoint file

# Create folder for saving images if it doesn't exist
if not os.path.exists(output_folder):
    os.makedirs(output_folder)

# Read the data from an Excel file
data = pd.read_excel(data_path, sheet_name="Data")

# Convert columns (except 'Month') to numeric, forcing errors to NaN
for col in data.columns:
    if col != "Month":
        data[col] = pd.to_numeric(data[col], errors='coerce')

# Replace NA values with 0
data.fillna(0, inplace=True)

# Remove 'Brand_PH_Avg_Price' column if it exists
if "Brand_PH_Avg_Price" in data.columns:
    data.drop(columns=["Brand_PH_Avg_Price"], inplace=True)

# Replace NA values with 0 after column removal
data.fillna(0, inplace=True)

# Initialize a counter for plot filenames
count = 0

# Create PowerPoint presentation
prs = Presentation()
prs.slide_width = Inches(16)
prs.slide_height = Inches(9)

# Add title slide
lyt = prs.slide_layouts[5]
slide = prs.slides.add_slide(lyt)
title = slide.shapes.title
title.text = "Cross Correlation Chart Automation for Market Mix Modeling"

# Loop through each column (except 'Month') and generate the CCF plot
for col in data.columns:
    if col != "Month":
        count += 1
        
        # Compute the cross-correlation function (CCF) for the series
        backwards = ccf(data['Sales_Revenue_Total'][::-1], data[col][::-1], adjusted=False)[::-1]
        forwards = ccf(data['Sales_Revenue_Total'], data[col], adjusted=False)
        ccf_vals = np.r_[backwards[:-1], forwards]

        # Define the lag range from -4 to 4
        #lags = np.arange(-4, 5)  # Lag range from -4 to 4
        
        # Slice the ccf_vals array to match the lag range
        # The ccf function returns 2*lag+1 values, so we need to slice to match lags from -4 to 4
        start = len(ccf_vals) // 2 - 4  # Middle of the array minus 4 for the left lags
        end = len(ccf_vals) // 2 + 5  # Middle of the array plus 5 for the right lags
        ccf_vals_lagged = ccf_vals[start:end]  # Extract values for lags from -4 to 4

        # Plot the CCF values with vertical lines at each lag
        plt.figure(figsize=(16, 9))
        plt.stem(range(-4, 5), ccf_vals_lagged, linefmt= "k", markerfmt= "", basefmt= "w")
        # 95% UCL / LCL
        plt.axhline(-1.96/np.sqrt(len(forwards)), color='b', ls='--') 
        plt.axhline(1.96/np.sqrt(len(forwards)), color='b', ls='--')
        plt.axhline(0, color='r', ls='-') 
        plt.title(f"Sales Revenue Total Vs {col}", fontsize = 16, weight = 'bold')
        plt.xlabel("Lag", fontsize = 12, weight = 'bold')
        plt.ylabel("CCF", fontsize = 12, weight = 'bold')
        plt.xticks(fontsize=12)
        plt.yticks(fontsize=12)
        #plt.grid(True)

        # Save the plot as a PNG file in the specified folder
        plot_filename = os.path.join(output_folder, f"plot_{count}.png")
        plt.savefig(plot_filename)
        plt.close()

        # Add the image to the PowerPoint slide
        blank_slide_layout = prs.slide_layouts[6]
        slide = prs.slides.add_slide(blank_slide_layout)
        left = Inches(0)
        top = Inches(0)
        img = slide.shapes.add_picture(plot_filename, left, top)

# Add final "Thank You" slide
last = prs.slide_layouts[0]
end_slide = prs.slides.add_slide(last)
title = end_slide.shapes.title
subtitle = end_slide.placeholders[1]
title.text = "Thank You !!!"
subtitle.text = "All Rights Reserved by Aryma Labs"

# Save the PowerPoint presentation
prs.save(save_path)

print(f"PowerPoint presentation saved at {save_path}")
