# -*- coding: utf-8 -*-
"""
Created on Mon Jan 13 12:22:38 2025

@author: admin
"""

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# Create the correlation data
data = pd.read_excel(r"D:\Febin\MMM Workshop\MMM Workshop Python Scripts\Correlation Heatmap\Correlation heatmap data.xlsx")

# Convert to DataFrame
df = pd.DataFrame(data)
df.set_index("Correlations", inplace=True)

# Transform the DataFrame for plotting
df_long = df.reset_index().melt(id_vars="Correlations", var_name="Variable2", value_name="Correlation")
df_long["AbsCorrelation"] = df_long["Correlation"].abs()  # Add column for absolute correlation

# Plot settings with proportional circle sizes
fig, ax = plt.subplots(figsize=(12, 7))
scatter = sns.scatterplot(
    data=df_long,
    x="Correlations",
    y="Variable2",
    size="AbsCorrelation",  # Use absolute correlation for size
    sizes=(100, 2000),  # Adjust size range for better visibility
    hue="Correlation",  # Color by actual correlation value (with sign)
    palette="coolwarm_r",  # Reversed palette
    legend=None,
    edgecolor="black",  # Ensure clear bubble borders
    linewidth=0.5,
    marker="o",  # Use circle markers
)

# Get the index of the Correlations and Variable2 for adjusting text positions
correlation_labels = df_long["Correlations"].unique()
variable2_labels = df_long["Variable2"].unique()

# Create a dictionary to map the labels to their positions
correlation_positions = {label: idx for idx, label in enumerate(correlation_labels)}
variable2_positions = {label: idx for idx, label in enumerate(variable2_labels)}

# Add annotations inside the circles with bold labels
for i in range(len(df_long)):
    value = df_long["Correlation"][i]
    x = correlation_positions[df_long["Correlations"][i]]
    y = variable2_positions[df_long["Variable2"][i]]
    
    if not np.isnan(value):  # Check if value is not NaN
        # Create the annotation and add to the list
        text = ax.text(
            x=x+0.25,
            y=y-0.2,
            s=f"{value*100:.1f}%",  # Display as percentage with one decimal place
            ha="center",
            va="center",
            fontsize=9,
            color="black",
            weight="bold",  # Make the text bold
        )

# Customizing the chart
plt.title("Correlation Heatmap", fontsize=16, weight="bold")
plt.xlabel("")
plt.ylabel("")
plt.xticks(fontsize=10, rotation=0)
plt.yticks(fontsize=10)
plt.grid(False)
plt.tight_layout()

ax.set_xlim(-0.3, len(correlation_labels) - 0.5)  # Adjust x-limits to fit the labels
ax.set_ylim(-0.3, len(variable2_labels) - 0.5)  # Adjust y-limits to fit the labels

# Add some padding to the edges to prevent the text from going outside the plot
#plt.subplots_adjust(left=0.1, right=0.1, top=0.1, bottom=0.1)

# Add color bar on top
norm = plt.Normalize(vmin=-1, vmax=1)
sm = plt.cm.ScalarMappable(cmap="coolwarm_r", norm=norm)
sm.set_array([])
cbar = plt.colorbar(sm, ax = ax, orientation="horizontal", pad=0.1, aspect=40, shrink=0.8, location="top")
cbar.set_label("Correlation", fontsize=12)

# Show the plot
plt.savefig("D:/Febin/MMM Workshop/MMM Workshop automated EDA charts/correlation_heatmap2.png")
plt.show()
