# -*- coding: utf-8 -*-
"""
Created function to make the dual axis line chart.

:param data: dataframe in which we have all the variable including month and both the variable on which line chart will be made
:type data: DataFrame
This function will make dual axis chart of all the columns available one by one, until all the columns are covered and each time will compare 
with KPI over the different time periods then further will create the image in ".png" format of all these comparisons,
and then finally create a presentation embedding all these images in that presentation by the name "automated_linechart.pptx"


"""
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib import style
from pptx import Presentation
from pptx.util import Inches
import os
from matplotlib.axis import Axis  
import matplotlib.ticker as ticker

file_path = r"C:\Users\admin\Downloads\MMM Workshop Deck\MMM_Workshop_Data.xlsx"
excel_sheet_name = "Data"
save_ppt_directory = r"C:\Users\admin\Downloads\MMM Workshop Deck\automated_linechart.pptx"


def automate_line(data):
    try:
        prs = Presentation()
        prs.slide_width = Inches(16)
        prs.slide_height = Inches(9)
        lyt=prs.slide_layouts[5]
        slide=prs.slides.add_slide(lyt)
        title=slide.shapes.title
        title.text="Dual Axis Line Chart Automation for Market Mix Modeling"

        for i in range(2, len(data.columns)):

            fig, ax = plt.subplots(figsize = (14, 8))
            #plt.style.use('Solarize_Light2')
            plt.title('{} v/s {}'.format(data.columns[1].replace("_"," "), data.columns[i].replace("_", " ")))
            plt.xticks(rotation = 90)
            ax.plot(data['Month'], data.iloc[:, 1], color = 'g', linewidth = 1.5)
            ax.set_xlabel("Month",fontsize = 'medium')
            ax.set_ylabel("{}".format(data.columns[1].replace("_", " ")),color="g", fontsize=14)
            ax.ticklabel_format(axis = 'y', style='plain')
            ax.set_ylim(0, (data.iloc[:, 1].max()+data.iloc[:, 1].max()* 0.1))
            formatter = ticker.FuncFormatter(lambda x, p: format(int(x), ','))
            Axis.set_major_formatter(ax.yaxis, formatter)
            ax2 = ax.twinx()
            ax2.plot(data['Month'], data.iloc[:, i], color = 'b', linewidth = 1.5)
            fig.legend(['{}'.format(data.columns[1].replace("_", " ")), '{}'.format(data.columns[i].replace("_", " "))], loc = 'upper right')
            ax2.ticklabel_format(axis = 'y', style='plain')
            ax2.set_ylim(0, (data.iloc[:, i].max()+data.iloc[:, i].max()*0.1))
            formatter = ticker.FuncFormatter(lambda x, p: format(int(x), ','))
            Axis.set_major_formatter(ax2.yaxis, formatter)
            ax2.set_ylabel("{}".format(data.columns[i].replace("_", " ")), color = 'b', fontsize = 14)
            plt.savefig('MMM_line_{}.png'.format(i))
            path = 'MMM_line_{}.png'.format(i)
            blank_slide_layout = prs.slide_layouts[6]
            slide = prs.slides.add_slide(blank_slide_layout)
            left=Inches(1)
            top=Inches(0.5)
            img=slide.shapes.add_picture(path,left,top)  
            #os.remove(path)  #use only if you don't want these images to get saved in your device, otherwise comment it out
            #plt.show()
        last=prs.slide_layouts[0]
        end_slide=prs.slides.add_slide(last)
        title=end_slide.shapes.title
        subtitle = end_slide.placeholders[1]
        title.text="Thank You !!!"
        subtitle.text = "All Rights Reserved by Aryma Labs"
        prs.save(save_ppt_directory)
    except KeyboardInterrupt:

        print('User ended the script')






Workshop_data = pd.read_excel(file_path, sheet_name= excel_sheet_name)
Workshop_data_copy = Workshop_data.fillna(0)

automate_line(Workshop_data_copy)



    