library(tidyverse)
library(readxl)

data <- read_excel("/Correlation heatmap.xlsx")

cor_tidy <- data %>%
  pivot_longer(cols = -Correlations, names_to = "Variable2", values_to = "Correlation") %>%
  rename(Variable1 = Correlations)

# Define the desired order for x-axis variables
desired_order <- c("Sales Volume", "Weighted Distribution", "TV GRP", "Price")

# Reorder variables in the x-axis
cor_tidy <- cor_tidy %>%
  mutate(
    Variable1 = factor(Variable1, levels = desired_order))

reversed_filtered_cov <- cor_tidy |> 
  mutate(
    lvl_a = as.numeric(Variable1),
    lvl_b = as.numeric(Variable2 |> fct_rev()),
    correlation = if_else(Variable1 > Variable2, Correlation, NA)
  ) 

MM_heatmap <- ggplot(cor_tidy, aes(x = Variable1, y = Variable2)) +
  geom_tile(fill = 'white', col = 'white') +
  geom_point(
    aes(fill = Correlation, size = abs(Correlation)),
    shape = 21
  ) +
  geom_text(
    data = reversed_filtered_cov,
    aes(label = paste0(round(Correlation * 100, 1), "%")),
    color = 'black',
    size = 3.5,
    family = 'Calibri',
    fontface = 'bold',
    vjust = 3.6,
    hjust = -0.6 
  ) +
  theme_minimal(
    base_size = 14,
    base_family = 'Calibri'
  ) +
  labs(
    x = element_blank(),
    y = element_blank(),
    fill = 'Correlation',
    title = "Correlation Heatmap"
  ) +
  scale_fill_gradient2(
    high = 'dodgerblue4',
    mid = 'white',
    low = 'firebrick2',
    limits = c(-0.8, 0.8),
    midpoint = 0
  ) +
  scale_size_area(
    limits = c(0, 1),
    max_size = 20
  ) +
  coord_cartesian(expand = FALSE) +
  theme(
    legend.position = 'top',
    panel.grid = element_blank(),
    panel.background = element_rect(fill = "white", color = NA),
    axis.text.x = element_text(angle = 0, hjust = 1)
  ) +
  guides(
    fill = guide_colorbar(
      barwidth = unit(10, 'cm')
    ),
    size = guide_none(),
    x = guide_axis(n.dodge = 2)
  )

ggsave(
  filename = "Bump charts Sales models/Heatmap_correlation_charts.png",
  plot = MM_heatmap,
  device = "png",
  width = 10, 
  height = 6, 
  dpi = 300
)
